<?php

namespace Api\PhpServices\XhProfiler;


use Xhgui\Profiler\Profiler;

class XhProfilerService
{
    private $profiler;

    public function __construct($domain)
    {
       // 根据域名读取 配置

        $this->profiler =  new Profiler([]);
    }

    /**
     * 开启 xhprofiler 分析
     * @param $domain
     */
    public function start($domain): void
    {
        //根据域名选择开不开启 分析
        if ($this->judgeSwitch($domain) === false)
        {
            return ;
        }
        //开启 分析器，并且初始化 mongodb 实例
        $this->profiler->start();
    }

    /**
     * 结束分析 并且 根据域名存储到不同的 mongodb collection 中
     * @param $domain
     */
    public function end($domain): void
    {
        //根据域名选择开不开启 分析
        if ($this->judgeSwitch($domain) === false)
        {
            return ;
        }

        // 结束分析器，生产性能检测数据
        $profiler_data = $this->profiler->disable();

        $profiler_data = $this->dealProfile($profiler_data,$domain);

        $mongo = XhMongo::getInstance();
        $mongo->insertOne($profiler_data);

    }

    private function dealProfile(array $profile,$domain)
    {
        $profile['profile'] = $this->encodeProfile($profile['profile']);
        $profile['env'] = $domain;
        return $profile;
    }

    private function encodeProfile(array $profile)
    {
        $results = array();
        foreach ($profile as $k => $v) {
            if (strpos($k, '.') !== false) {
                $k = str_replace('.', '_', $k);
            }
            $results[$k] = $v;
        }

        return $results;
    }


    /**
     * 开关决策器
     * @param $domain
     * @return bool
     */
    private function judgeSwitch($domain)
    {
        // 从 yaconf 获取配置 ，判断当前域名是否要开启
        return true;
    }
}